@@ -1,9 +1,9 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-07-06 12:44:38 mtw>
+# Last changed Time-stamp: <2015-10-27 14:48:09 mtw>
 
 package Bio::ViennaNGS;
 
-use version; our $VERSION = qv('0.15');
+use version; our $VERSION = qv('0.16');
 
 1;
 
@@ -40,6 +40,9 @@ processing L<Bio::ViennaNGS::BamStat> objects on a set of BAM files.
 =item L<Bio::ViennaNGS::Bed>: A L<Moose> interface for manipulation of
 genomic interval data in BED format.
 
+=item L<Bio::ViennaNGS::BedGraphEntry>: A L<Moose> interface for
+storing genomic cvoerage and interval data in bedGraph format.
+
 =item L<Bio::ViennaNGS::Expression>: An object oriented interface for
 read-count based gene expression analysis.
 
@@ -55,11 +58,20 @@ L<Bio::DB::Fasta>.
 =item L<Bio::ViennaNGS::FeatureChain>: Yet another L<Moose> class for
 chaining gene annotation features.
 
+=item L<Bio::ViennaNGS::FeatureInterval>: A L<Moose> interface for
+handling elementary genomic intervals, corresponding to BED3.
+
+=item L<Bio::ViennaNGS::FeatureIO>: A L<Moose> interface for efficient
+input/output handling of genomic annotation formats.
+
 =item L<Bio::ViennaNGS::FeatureLine>: An abstract L<Moose> class for
 combining several L<Bio::ViennaNGS::FeatureChain> objects.
 
 =item L<Bio::ViennaNGS::MinimalFeature>: A L<Moose> interface for
-handling elementary gene annotation.
+handling elementary gene annotation, corresponding to BED4.
+
+=item L<Bio::ViennaNGS::Peak>: A L<Moose> interface for identification
+and characterization of peaks/enriched regions in RNA-seq data.
 
 =item L<Bio::ViennaNGS::SpliceJunc>: A collection of routines for
 alternative splicing analysis.
@@ -113,6 +125,9 @@ bedGraph files, allowing additional annotation and automatic
 generation of bedGraph files which can easily be converted to big-type
 files for easy UCSC visualization.
 
+=item F<bed2nt2aa.pl>: Provide nucleotide and amino acid sequences for
+BED6 intervals.
+
 =item F<extend_bed.pl>: Extend genomic features in BED files by a
 certain number of nucleotides, either on both sides or specifically at
 the 5' or 3' end, respectively.
@@ -135,7 +150,10 @@ article|http://genomewiki.ucsc.edu/index.php/Building_a_new_genome_database>.
 
 =item F<normalize_multicov.pl>: Compute normalized expression data in
 RPKM and TPM from (raw) read counts in bedtools multicov format. TPM
-reference: Wagner et al, Theory Biosci. 131(4), pp 281-85 (2012)
+reference: Wagner et al, Theory Biosci. 131(4), pp 281-85 (2012).
+
+=item F<rnaseq_peakfinder.pl>: Find and characterize peaks/enriched
+regions of certain size and coverage in RNA-seq data.
 
 =item F<sj_visualizer.pl>: Convert splice junctions from mapped
 RNA-seq data in segemehl BED6 splice junction format to BED12 for easy
@@ -169,8 +187,12 @@ modules, some of which are part of the Perl core distribution:
 
 =item L<File::Share>
 
+=item L<File::Slurp>
+
 =item L<File::Temp>
 
+=item L<List::Util>
+
 =item L<Path::Class>
 
 =item L<IPC::Cmd>
@@ -191,6 +213,10 @@ modules, some of which are part of the Perl core distribution:
 
 =item L<Tie::Hash::Indexed>
 
+=item L<Test::Files>
+
+=item L<Test::File::Contents>
+
 =back
 
 In addition the following modules are required by the L<Bio::ViennaNGS> utilities:
@@ -245,7 +271,7 @@ analysis pipelines">
 
 I<Michael T. Wolfinger, Joerg Fallmann, Florian Eggenhofer and Fabian Amman>
 
-F1000Research 2015, 4:50 (doi: L<10.12688E<sol>f1000research.6157.1|http://dx.doi.org/10.12688/f1000research.6157.1>)
+F1000Research 2015, 4:50 (doi: L<10.12688E<sol>f1000research.6157.2|http://dx.doi.org/10.12688/f1000research.6157.2>)
 
 =head1 NOTES
 
@@ -270,6 +296,8 @@ test Windows compatibility.
 
 =item L<Bio::ViennaNGS::Bed>
 
+=item L<Bio::ViennaNGS::BedGraphEntry>
+
 =item L<Bio::ViennaNGS::Expression>
 
 =item L<Bio::ViennaNGS::ExtFeature>
@@ -280,10 +308,16 @@ test Windows compatibility.
 
 =item L<Bio::ViennaNGS::FeatureChain>
 
+=item L<Bio::ViennaNGS::FeatureIO>
+
+=item L<Bio::ViennaNGS::FeatureInterval>
+
 =item L<Bio::ViennaNGS::FeatureLine>
 
 =item L<Bio::ViennaNGS::MinimalFeature>
 
+=item L<Bio::ViennaNGS::Peak>
+
 =item L<Bio::ViennaNGS::SpliceJunc>
 
 =item L<Bio::ViennaNGS::Tutorial>
