@@ -1,12 +1,13 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-06-29 15:50:56 mtw>
+# Last changed Time-stamp: <2015-10-27 14:44:37 mtw>
 
 package Bio::ViennaNGS::Bed;
 
-use version; our $VERSION = qv('0.15');
+use version; our $VERSION = qv('0.16');
 use Carp;
 use Moose;
 use namespace::autoclean;
+use Data::Dumper;
 
 extends 'Bio::ViennaNGS::Feature';
 
@@ -76,6 +77,9 @@ sub _build_length {
 sub as_bed_line {
   my ($self,$n) = @_;
   my $this_function = (caller(0))[3];
+  croak "ERROR [$this_function] no argument provided"
+    unless (defined $n);
+  print Dumper(\$n);
   croak "ERROR [$this_function] argument of as_bed_line() must be 6 or 12"
     unless ( ($n == 6) | ($n == 12) );
   my $bed6= join ("\t",
@@ -131,12 +135,12 @@ genomic interval data in BED format
 
 =head1 DESCRIPTION
 
-This module provides a Moose interface for storage and manipulation of
-genomic interval data. It is primarily used as a convenience wrapper
-for BED data with more generic L<Bio::ViennaNGS> classes for feature
-annotation, such as L<Bio::ViennaNGS::MinimalFeature>,
-L<Bio::ViennaNGS::Feature>, L<Bio::ViennaNGS::FeatureChain> and
-L<Bio::ViennaNGS::FeatureLine>.
+This module provides a L<Moose> interface for storage and manipulation
+of genomic interval data. It is primarily used as a convenience
+wrapper for BED data with more generic L<Bio::ViennaNGS> classes for
+feature annotation, such as L<Bio::ViennaNGS::FeatureInterval>,
+L<Bio::ViennaNGS::MinimalFeature>, L<Bio::ViennaNGS::Feature>,
+L<Bio::ViennaNGS::FeatureChain> and L<Bio::ViennaNGS::FeatureLine>.
 
 =head1 METHODS
 
