@@ -1,18 +1,17 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2018-07-03 12:20:53 mtw>
+# Last changed Time-stamp: <2015-10-27 17:31:43 mtw>
 
 package Bio::ViennaNGS::Peak;
 
-use Bio::ViennaNGS;
+use version; our $VERSION = qv('0.16');
 use Moose;
 use Carp;
 use Data::Dumper;
 use Path::Class;
 use List::Util qw(sum sum0 min max first);
 use Bio::ViennaNGS::Util qw(sortbed);
+
 use namespace::autoclean;
-use File::Temp qw(tempfile);
-use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 has 'data' => (
 	       is => 'ro',
@@ -41,6 +40,12 @@ has 'winsize' => (
 		  predicate => 'has_winsize',
 		 );
 
+has 'winsize' => (
+		  is => 'ro',
+		  isa => 'Int',
+		  predicate => 'has_winsize',
+		 );
+
 has 'interval' => (
 		   is => 'ro',
 		   isa => 'Int',
@@ -115,21 +120,23 @@ sub populate_data {
 
 sub raw_peaks {
   my ($self,$dest,$prefix,$log) = @_;
-  my ($fn,$tfn,$tfh,$maxidx,$have_pstart,$pstart,$pend,$chr);
+  my ($fn,$fn_u,$outfile,$maxidx,$have_pstart,$pstart,$pend,$chr);
   my ($winstart, $winend, $winsum, $mean, $lastmax, $from, $to);
   my ($index_of_maxwin);
   my $suffix = "rawpeaks.bed";
   my $this_function = (caller(0))[3];
-  my $flex = 10;
 
   croak "ERROR [$this_function]: $dest does not exist\n"
     unless (-d $dest);
 
-  if (defined $log){open(LOG, ">", $log) or croak "$!"}
+  if (defined $log){
+    open(LOG, ">", $log) or croak "$!";
+  }
   else {croak "ERROR [$this_function] \$log not defined";}
 
-  $fn = $prefix.".".$suffix;   # filename of final, sorted RAWPEAKS bed file
-  (undef,$tfn) = tempfile('RAWPEAKS_XXXXXXX',UNLINK=>0);
+  $fn   = $prefix.".".$suffix;
+  $fn_u = $prefix.".u.".$suffix;
+  $outfile = file($dest,$fn_u);
 
   croak "ERROR [$this_function]: $self->data not available\n"
     unless ($self->has_data);
@@ -137,7 +144,7 @@ sub raw_peaks {
   croak "ERROR [$this_function]: $self->region not available\n"
     unless ($self->has_region);
 
-  open ($tfh, ">", $tfn) or croak $!;
+  open(RAWPEAKS, ">", $fn_u) or croak $!;
   $lastmax = 0;
   foreach $chr (keys (%{$self->data})){
 
@@ -146,7 +153,7 @@ sub raw_peaks {
     $have_pstart = 0;
     $pstart      = -1;
     $pend        = -1;
-    if (defined $log){print LOG "processing chr $chr [+] strand $maxidx\n"}
+    print LOG "processing chr $chr [+] strand $maxidx\n";
     croak "$chr has not been parsed in input data"
       unless (exists $self->region->{$chr}{pos}{start});
 
@@ -155,7 +162,7 @@ sub raw_peaks {
       $winend = $winstart + $self->winsize - 1;
       $winsum = sum0 @{$self->data->{$chr}{pos}}[$winstart..$winend];
       $mean = $winsum/$self->winsize;
-       #print LOG "**processing $winstart - $winend sum=$winsum mean=$mean lastmax=$lastmax\n";
+      # print "processing $winstart - $winend sum=$winsum mean=$mean lastmax=$lastmax\n";
 
       if ($mean > $lastmax){
 	$lastmax = $mean;
@@ -163,7 +170,7 @@ sub raw_peaks {
 	unless ($have_pstart == 1) {
 	  $pstart = $winstart;
 	  $have_pstart = 1;
-	  #print LOG "Peak start $chr:$winstart -- ";
+	  #print "Peak start $chr:$winstart -- ";
 	}
       }
       else {
@@ -172,12 +179,7 @@ sub raw_peaks {
 	  $have_pstart = 0;
 	  $from = min($pstart,$pend);
 	  $to   = max($pstart, $pend);
-	  next if ($from<0);
-	  next if ($to<0);
-	  # now add +- $flex nt to raw peaks, required fro better peak boundary determination below
-	  if ($from-$flex > 0){$from = $from - $flex;}
-	  $to= $to+$flex; # we dont know the chromsize here, hence override it in case
-	  #print LOG "$pend end\n";
+	  #print "$pend end\n";
 	  my %pk = (
 		    chr      => $chr,
 		    start    => $from,
@@ -186,8 +188,8 @@ sub raw_peaks {
 		    maxindex => $index_of_maxwin,
 		   );
 	  push (@{ $self->peaks->{$chr} }, \%pk);
-	  if (defined $log){print LOG "**PEAK $chr [+] $from-$to max at $index_of_maxwin\n"}
-	  print $tfh "$chr\t$from\t$to\tRAW\t0\t+\n";
+	  print LOG "**PEAK $chr [+] $from-$to max at $index_of_maxwin\n";
+	  print RAWPEAKS "$chr\t$from\t$to\tRAW\t0\t+\n";
 
 	  # reset parameters
 	  $lastmax = 0;
@@ -203,7 +205,7 @@ sub raw_peaks {
     $have_pstart = 0;
     $pstart      = -1;
     $pend        = -1;
-    if (defined $log){print LOG "processing chr $chr [-] strand $maxidx\n"}
+    print LOG "processing chr $chr [-] strand $maxidx\n";
     croak "$chr has not been parsed in input data"
       unless (exists $self->region->{$chr}{neg}{start});
 
@@ -229,11 +231,6 @@ sub raw_peaks {
 	  $have_pstart = 0;
 	  $from = min($pstart,$pend);
 	  $to   = max($pstart, $pend);
-	  next if ($from<0);
-	  next if ($to<0);
-	  # now add +- $flex nt to raw peaks, required fro better peak boundary determination below
-	  if ($from-$flex > 0){$from = $from - $flex;}
-	  $to = $to+$flex; # we dont know the chromsize here, hence override it in case
 	  #print "$pend end\n";
 	  my %pk = (
 		    chr    => $chr,
@@ -243,8 +240,8 @@ sub raw_peaks {
 		    maxindex => $index_of_maxwin,
 		   );
 	  push (@{ $self->peaks->{$chr} }, \%pk);
-	  if (defined $log){print LOG "**PEAK $chr [-] $from-$to max at $index_of_maxwin\n"}
-	  print $tfh "$chr\t$from\t$to\tRAW\t0\t-\n";
+	  print LOG "**PEAK $chr [-] $from-$to max at $index_of_maxwin\n"; 
+	  print RAWPEAKS "$chr\t$from\t$to\tRAW\t0\t-\n";
 
 	  # reset parameters
 	  $lastmax = 0;
@@ -257,26 +254,28 @@ sub raw_peaks {
     #print LOG Dumper($self->peaks);
 
   } # end foreach
-  close($tfh);
+  close(RAWPEAKS);
   close(LOG);
-  sortbed($tfn,$dest,$fn,0,$log);
-  unlink($tfn);
+  sortbed($fn_u,$dest,$fn,1,$log);
 }
 
 sub final_peaks {
   my ($self,$dest,$prefix,$log) = @_;
-  my ($fn,$tfn,$tfh,$strand,$max,$idx,$val,$peak,$position,$pleft,$pright,$str);
+  my ($fn,$fn_u,$outfile,$strand,$max,$idx,$val,$peak,$position,$pleft,$pright,$str);
   my $suffix = "candidatepeaks.bed";
   my $this_function = (caller(0))[3];
 
   croak "ERROR [$this_function]: $dest does not exist\n"
     unless (-d $dest);
 
-  if (defined $log){open(LOG, ">>", $log) or croak "$!";}
+  if (defined $log){
+    open(LOG, ">>", $log) or croak "$!";
+  }
   else {croak "ERROR [$this_function] \$log not defined";}
 
   $fn   = $prefix.".".$suffix;
-  (undef,$tfn) = tempfile('CANDIDATEPEAKS_XXXXXXX',UNLINK=>0);
+  $fn_u = $prefix.".u.".$suffix;
+  $outfile = file($dest,$fn_u);
 
   croak "ERROR [$this_function]: $self->data not available\n"
     unless ($self->has_data);
@@ -284,21 +283,20 @@ sub final_peaks {
   croak "ERROR [$this_function]: $self->peaks not available\n"
     unless ($self->has_peaks);
 
-  open($tfh, ">", $tfn) or croak $!;
+  open(CANDIDATEPEAKS, ">", $fn_u) or croak $!;
+
   foreach my $chr (keys (%{$self->peaks})){
-    if (defined $log){print LOG "filtering candidate peaks in $chr\n";}
+    print LOG "filtering candidate peaks in $chr\n";
 
     foreach $peak ( @{$self->peaks->{$chr}}){
       my $have_pleft = 0; # we have found a proper left end
       my $have_pright = 0; # we have found a proper right end
       $strand = $$peak{strand};
-      if (defined $log){print LOG ">>processing peak $$peak{start}-$$peak{end} [$strand] ";}
       $max = max @{$self->data->{$chr}{$strand}}[$$peak{start}..$$peak{end}]; # max peak elevation
-      if (defined $log){print LOG "max is $max";}
-      if ($max < $self->mincov){print LOG " ..SKIPPING\n";next;}
+      next if ($max < $self->mincov);
       $idx = first { @{$self->data->{$chr}{$strand}}[$_] eq $max } $$peak{start}..$$peak{end}; # coordinate
       #print LOG Dumper(\$peak);
-      if (defined $log){print LOG " at $idx ..KEEPING\n";}
+      print LOG "max in window $$peak{start}..$$peak{end} is $max at $idx\n";
 
       # process regions left/right of the maximum to identify peak boundaries
       # validity check first
@@ -308,30 +306,26 @@ sub final_peaks {
       # find left end
       for ($position = $idx; $position>$$peak{start}; $position--){
 	$val =  ${$self->data->{$chr}{$strand}}[$position];
-	if (defined $log){print LOG "** VAL_L at pos $position $val - \$have_pleft=$have_pleft ";}
+	#print "* VAL_L at pos $position $val - \$have_pleft=$have_pleft ";
 	if ( $val < $max*$self->threshold){
 	  $have_pleft = 1;
-	  if (defined $log){
-	    print LOG "exiting 'cause $val < ".$max*$self->threshold." - \$have_pleft=$have_pleft\n";
-	  }
+	  #print "exiting 'cause $val < ".$max*$threshold." - \$have_pleft=$have_pleft\n";
 	  last;
 	}
-	if (defined $log){print LOG "\n";}
+	#print "\n";
       }
       $pleft = $position;
 
       # find right end
       for ($position = $idx; $position<=$$peak{end}; $position++){
 	$val =  ${$self->data->{$chr}{$strand}}[$position];
-	if (defined $log){print LOG "** VAL_R at pos $position $val - \$have_pright=$have_pright ";}
+	#print "* VAL_R at pos $position $val - \$have_pright=$have_pright ";
 	if ( $val < $max*$self->threshold){
 	  $have_pright = 1;
-	  if (defined $log){
-	    print LOG "exiting 'cause $val < ".$max*$self->threshold."- \$have_pright=$have_pright\n";
-	  }
+	  #print "exiting 'cause $val < ".$max*$threshold."- \$have_pright=$have_pright\n";
 	  last;
 	}
-	if (defined $log){print LOG "\n";}
+	#print "\n";
       }
       $pright = $position;
       if ($strand eq "neg"){
@@ -340,18 +334,17 @@ sub final_peaks {
       else{
 	$str = '+';
       }
-      if (defined $log){print LOG "# PEAK characterized at $chr:$pleft-$pright\n";}
+      #print LOG "# PEAK characterized at $chr:$pleft-$pright\n";
 
       if ($have_pleft == 1 && $have_pright == 1){ # print only if its a proper peak
 	if ($pright-$pleft<=$self->length){ # filter peak length 
-	  if (defined $log){print $tfh "$chr\t$pleft\t$pright\tCANDIDATE\t$max\t$str\n";}
+	  print CANDIDATEPEAKS "$chr\t$pleft\t$pright\tCANDIDATE\t$max\t$str\n";
 	}
       }
     } # end foreach $peak
   } # end foreach $chr
-  close($tfh);
-  sortbed($tfn,$dest,$fn,0,$log);
-  unlink($tfn);
+  close(CANDIDATEPEAKS);
+  sortbed($fn_u,$dest,$fn,1,$log);
 }
 __PACKAGE__->meta->make_immutable;
 
@@ -507,7 +500,7 @@ Michael T. Wolfinger, E<lt>michael@wolfinger.euE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015-2018 by Michael T. Wolfinger
+Copyright (C) 2015 by Michael T. Wolfinger
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
